/*
 * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.TimeZoneNamesBundle;

public class TimeZoneNames_br extends TimeZoneNamesBundle {
    @Override
    protected final Object[][] getContents() {
        final String[] GMT = new String[] {
               "Amzer keitat Greenwich (AKG)",
               "GMT",
               "",
               "GMT",
               "",
               "GMT",
            };
        final String[] Apia = new String[] {
               "eur c\u02bchoa\u00f1v Apia",
               "",
               "eur ha\u00f1v Apia",
               "",
               "eur Apia",
               "",
            };
        final String[] Cook = new String[] {
               "eur c\u02bchoa\u00f1v Inizi Cook",
               "",
               "eur ha\u00f1v Inizi Cook",
               "",
               "eur Inizi Cook",
               "",
            };
        final String[] Cuba = new String[] {
               "eur c\u02bchoa\u00f1v Kuba",
               "CST",
               "eur ha\u00f1v Kuba",
               "CDT",
               "eur Kuba",
               "CT",
            };
        final String[] Fiji = new String[] {
               "eur c\u02bchoa\u00f1v Fidji",
               "",
               "eur ha\u00f1v Fidji",
               "",
               "eur Fidji",
               "",
            };
        final String[] Gulf = new String[] {
               "eur c\u02bchoa\u00f1v ar Pleg-mor Arab-ha-Pers",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Hovd = new String[] {
               "eur c\u02bchoa\u00f1v Hovd",
               "",
               "eur ha\u00f1v Hovd",
               "",
               "eur Hovd",
               "",
            };
        final String[] Iran = new String[] {
               "eur c\u02bchoa\u00f1v Iran",
               "",
               "eur ha\u00f1v Iran",
               "",
               "eur Iran",
               "",
            };
        final String[] Niue = new String[] {
               "eur Niue",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Omsk = new String[] {
               "eur c\u02bchoa\u00f1v Omsk",
               "",
               "eur ha\u00f1v Omsk",
               "",
               "eur Omsk",
               "",
            };
        final String[] Peru = new String[] {
               "eur c\u02bchoa\u00f1v Perou",
               "",
               "eur ha\u00f1v Perou",
               "",
               "eur Perou",
               "",
            };
        final String[] Truk = new String[] {
               "eur Chuuk",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Wake = new String[] {
               "eur Wake Island",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Chile = new String[] {
               "eur c\u02bchoa\u00f1v Chile",
               "",
               "eur ha\u00f1v Chile",
               "",
               "eur Chile",
               "",
            };
        final String[] China = new String[] {
               "eur c\u02bchoa\u00f1v Sina",
               "CST",
               "eur ha\u00f1v Sina",
               "CDT",
               "eur Sina",
               "CT",
            };
        final String[] Cocos = new String[] {
               "eur Inizi Kokoz",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Davis = new String[] {
               "eur Davis",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] India = new String[] {
               "eur c\u02bchoa\u00f1v India",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Japan = new String[] {
               "eur c\u02bchoa\u00f1v Japan",
               "JST",
               "eur ha\u00f1v Japan",
               "JDT",
               "eur Japan",
               "JT",
            };
        final String[] Korea = new String[] {
               "eur c\u02bchoa\u00f1v Korea",
               "KST",
               "eur ha\u00f1v Korea",
               "KST",
               "eur Korea",
               "KST",
            };
        final String[] Nauru = new String[] {
               "eur Nauru",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Nepal = new String[] {
               "eur Nepal",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Palau = new String[] {
               "eur Palau",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Samoa = new String[] {
               "eur c\u02bchoa\u00f1v Samoa",
               "SST",
               "eur ha\u00f1v Samoa",
               "SST",
               "eur Samoa",
               "SST",
            };
        final String[] Syowa = new String[] {
               "eur Syowa",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Tonga = new String[] {
               "eur c\u02bchoa\u00f1v Tonga",
               "",
               "eur ha\u00f1v Tonga",
               "",
               "eur Tonga",
               "",
            };
        final String[] Alaska = new String[] {
               "eur c\u02bchoa\u00f1v Alaska",
               "AKST",
               "eur ha\u00f1v Alaska",
               "AKDT",
               "eur Alaska",
               "AKT",
            };
        final String[] Amazon = new String[] {
               "eur c\u02bchoa\u00f1v an Amazon",
               "",
               "eur ha\u00f1v an Amazon",
               "",
               "eur an Amazon",
               "",
            };
        final String[] Anadyr = new String[] {
               "eur c\u02bchoa\u00f1v Anadyr\u02bc",
               "",
               "eur ha\u00f1v Anadyr\u02bc",
               "",
               "eur Anadyr\u02bc",
               "",
            };
        final String[] Azores = new String[] {
               "eur c\u02bchoa\u00f1v an Azorez",
               "",
               "eur ha\u00f1v an Azorez",
               "",
               "eur an Azorez",
               "",
            };
        final String[] Bhutan = new String[] {
               "eur Bhoutan",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Brunei = new String[] {
               "eur Brunei Darussalam",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Easter = new String[] {
               "eur c\u02bchoa\u00f1v Enez Pask",
               "",
               "eur ha\u00f1v Enez Pask",
               "",
               "eur Enez Pask",
               "",
            };
        final String[] Guyana = new String[] {
               "eur Guyana",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Israel = new String[] {
               "eur c\u02bchoa\u00f1v Israel",
               "IST",
               "eur ha\u00f1v Israel",
               "IDT",
               "eur Israel",
               "IT",
            };
        final String[] Kosrae = new String[] {
               "eur Kosrae",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Mawson = new String[] {
               "eur Mawson",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Moscow = new String[] {
               "eur c\u02bchoa\u00f1v Moskov",
               "MSK",
               "eur ha\u00f1v Moskov",
               "MSK",
               "eur Moskov",
               "MSK",
            };
        final String[] Ponape = new String[] {
               "eur Pohnpei",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Tahiti = new String[] {
               "eur Tahiti",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Taipei = new String[] {
               "eur c\u02bchoa\u00f1v Taipei",
               "CST",
               "eur ha\u00f1v Taipei",
               "CDT",
               "eur Taipei",
               "CT",
            };
        final String[] Tuvalu = new String[] {
               "eur Tuvalu",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Vostok = new String[] {
               "eur Vostok",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Wallis = new String[] {
               "eur Wallis ha Futuna",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Arabian = new String[] {
               "eur c\u02bchoa\u00f1v Arabia",
               "",
               "eur ha\u00f1v Arabia",
               "",
               "eur Arabia",
               "",
            };
        final String[] Armenia = new String[] {
               "eur c\u02bchoa\u00f1v Armenia",
               "",
               "eur ha\u00f1v Armenia",
               "",
               "eur Armenia",
               "",
            };
        final String[] Bolivia = new String[] {
               "eur Bolivia",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Chatham = new String[] {
               "eur c\u02bchoa\u00f1v Chatham",
               "",
               "eur ha\u00f1v Chatham",
               "",
               "eur Chatham",
               "",
            };
        final String[] ETC_UTC = new String[] {
               "amzer hollvedel kenurzhiet",
               "UTC",
               "",
               "",
               "",
               "",
            };
        final String[] Ecuador = new String[] {
               "eur Ecuador",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Gambier = new String[] {
               "eur Inizi Gambier",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Georgia = new String[] {
               "eur c\u02bchoa\u00f1v Jorjia",
               "",
               "eur ha\u00f1v Jorjia",
               "",
               "eur Jorjia",
               "",
            };
        final String[] Irkutsk = new String[] {
               "eur c\u02bchoa\u00f1v Irkutsk",
               "",
               "eur ha\u00f1v Irkutsk",
               "",
               "eur Irkutsk",
               "",
            };
        final String[] Magadan = new String[] {
               "eur c\u02bchoa\u00f1v Magadan",
               "",
               "eur ha\u00f1v Magadan",
               "",
               "eur Magadan",
               "",
            };
        final String[] Myanmar = new String[] {
               "eur Myanmar",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Norfolk = new String[] {
               "eur c\u02bchoa\u00f1v Enez Norfolk",
               "",
               "eur ha\u00f1v Enez Norfolk",
               "",
               "eur Enez Norfolk",
               "",
            };
        final String[] Noronha = new String[] {
               "eur c\u02bchoa\u00f1v Fernando de Noronha",
               "",
               "eur ha\u00f1v Fernando de Noronha",
               "",
               "eur Fernando de Noronha",
               "",
            };
        final String[] Reunion = new String[] {
               "eur ar Re\u00fcnion",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Rothera = new String[] {
               "eur Rothera",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Solomon = new String[] {
               "eur Inizi Salomon",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Tokelau = new String[] {
               "eur Tokelau",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Uruguay = new String[] {
               "eur c\u02bchoa\u00f1v Uruguay",
               "",
               "eur ha\u00f1v Uruguay",
               "",
               "eur Uruguay",
               "",
            };
        final String[] Vanuatu = new String[] {
               "eur c\u02bchoa\u00f1v Vanuatu",
               "",
               "eur ha\u00f1v Vanuatu",
               "",
               "eur Vanuatu",
               "",
            };
        final String[] Yakutsk = new String[] {
               "eur c\u02bchoa\u00f1v Yakutsk",
               "",
               "eur ha\u00f1v Yakutsk",
               "",
               "eur Yakutsk",
               "",
            };
        final String[] Atlantic = new String[] {
               "eur c\u02bchoa\u00f1v an Atlantel",
               "AST",
               "eur ha\u00f1v an Atlantel",
               "ADT",
               "eur an Atlantel",
               "AT",
            };
        final String[] Brasilia = new String[] {
               "eur c\u02bchoa\u00f1v Bras\u00edlia",
               "",
               "eur ha\u00f1v Bras\u00edlia",
               "",
               "eur Bras\u00edlia",
               "",
            };
        final String[] Chamorro = new String[] {
               "eur Chamorro",
               "ChST",
               "",
               "ChST",
               "",
               "ChST",
            };
        final String[] Colombia = new String[] {
               "eur c\u02bchoa\u00f1v Kolombia",
               "",
               "eur ha\u00f1v Kolombia",
               "",
               "eur Kolombia",
               "",
            };
        final String[] Falkland = new String[] {
               "eur c\u02bchoa\u00f1v Inizi Falkland",
               "",
               "eur ha\u00f1v Inizi Falkland",
               "",
               "eur Inizi Falkland",
               "",
            };
        final String[] Malaysia = new String[] {
               "eur Malaysia",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Maldives = new String[] {
               "eur ar Maldivez",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Mongolia = new String[] {
               "eur c\u02bchoa\u00f1v Ulaanbaatar",
               "",
               "eur ha\u00f1v Ulaanbaatar",
               "",
               "eur Ulaanbaatar",
               "",
            };
        final String[] Pakistan = new String[] {
               "eur c\u02bchoa\u00f1v Pakistan",
               "PKT",
               "eur ha\u00f1v Pakistan",
               "PKST",
               "eur Pakistan",
               "PKT",
            };
        final String[] Paraguay = new String[] {
               "eur c\u02bchoa\u00f1v Paraguay",
               "",
               "eur ha\u00f1v Paraguay",
               "",
               "eur Paraguay",
               "",
            };
        final String[] Pitcairn = new String[] {
               "eur Pitcairn",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Sakhalin = new String[] {
               "eur c\u02bchoa\u00f1v Sakhalin",
               "",
               "eur ha\u00f1v Sakhalin",
               "",
               "eur Sakhalin",
               "",
            };
        final String[] Suriname = new String[] {
               "eur Surinam",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Argentina = new String[] {
               "eur c\u02bchoa\u00f1v Arc\u02bchantina",
               "",
               "eur ha\u00f1v Arc\u02bchantina",
               "",
               "eur Arc\u02bchantina",
               "",
            };
        final String[] Christmas = new String[] {
               "eur Enez Christmas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Galapagos = new String[] {
               "eur Inizi Gal\u00e1pagos",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Hong_Kong = new String[] {
               "eur c\u02bchoa\u00f1v Hong Kong",
               "HKT",
               "eur ha\u00f1v Hong Kong",
               "HKST",
               "eur Hong Kong",
               "HKT",
            };
        final String[] Indochina = new String[] {
               "eur Indez-Sina",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Kyrgystan = new String[] {
               "eur Kyrgyzstan",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Lord_Howe = new String[] {
               "eur c\u02bchoa\u00f1v Lord Howe",
               "",
               "eur ha\u00f1v Lord Howe",
               "",
               "eur Lord Howe",
               "",
            };
        final String[] Marquesas = new String[] {
               "eur Inizi Markiz",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Mauritius = new String[] {
               "eur c\u02bchoa\u00f1v Moris",
               "",
               "eur ha\u00f1v Moris",
               "",
               "eur Moris",
               "",
            };
        final String[] Singapore = new String[] {
               "eur c\u02bchoa\u00f1v Singapour",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Venezuela = new String[] {
               "eur Venezuela",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Volgograd = new String[] {
               "eur c\u02bchoa\u00f1v Volgograd",
               "MSK",
               "eur ha\u00f1v Volgograd",
               "MSK",
               "eur Volgograd",
               "MSK",
            };
        final String[] Azerbaijan = new String[] {
               "eur c\u02bchoa\u00f1v Azerbaidjan",
               "",
               "eur ha\u00f1v Azerbaidjan",
               "",
               "eur Azerbaidjan",
               "",
            };
        final String[] Bangladesh = new String[] {
               "eur c\u02bchoa\u00f1v Bangladesh",
               "",
               "eur ha\u00f1v Bangladesh",
               "",
               "eur Bangladesh",
               "",
            };
        final String[] Cape_Verde = new String[] {
               "eur c\u02bchoa\u00f1v ar C\u02bchab-Glas",
               "",
               "eur ha\u00f1v ar C\u02bchab-Glas",
               "",
               "eur ar C\u02bchab-Glas",
               "",
            };
        final String[] East_Timor = new String[] {
               "eur Timor ar Reter",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Seychelles = new String[] {
               "eur Sechelez",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Tajikistan = new String[] {
               "eur Tadjikistan",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Uzbekistan = new String[] {
               "eur c\u02bchoa\u00f1v Ouzbekistan",
               "",
               "eur ha\u00f1v Ouzbekistan",
               "",
               "eur Ouzbekistan",
               "",
            };
        final String[] Afghanistan = new String[] {
               "eur Afghanistan",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Krasnoyarsk = new String[] {
               "eur c\u02bchoa\u00f1v Krasnoyarsk",
               "",
               "eur ha\u00f1v Krasnoyarsk",
               "",
               "eur Krasnoyarsk",
               "",
            };
        final String[] New_Zealand = new String[] {
               "eur c\u02bchoa\u00f1v Zeland-Nevez",
               "NZST",
               "eur ha\u00f1v Zeland-Nevez",
               "NZDT",
               "eur Zeland-Nevez",
               "NZT",
            };
        final String[] Novosibirsk = new String[] {
               "eur c\u02bchoa\u00f1v Novosibirsk",
               "",
               "eur ha\u00f1v Novosibirsk",
               "",
               "eur Novosibirsk",
               "",
            };
        final String[] Philippines = new String[] {
               "eur c\u02bchoa\u00f1v ar Filipinez",
               "PST",
               "eur ha\u00f1v ar Filipinez",
               "PDT",
               "eur ar Filipinez",
               "PT",
            };
        final String[] Vladivostok = new String[] {
               "eur c\u02bchoa\u00f1v Vladivostok",
               "",
               "eur ha\u00f1v Vladivostok",
               "",
               "eur Vladivostok",
               "",
            };
        final String[] Indian_Ocean = new String[] {
               "eur Meurvor Indez",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Line_Islands = new String[] {
               "eur Line Islands",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Newfoundland = new String[] {
               "eur c\u02bchoa\u00f1v Newfoundland",
               "NST",
               "eur ha\u00f1v Newfoundland",
               "NDT",
               "eur Newfoundland",
               "NT",
            };
        final String[] Turkmenistan = new String[] {
               "eur c\u02bchoa\u00f1v Turkmenistan",
               "",
               "eur ha\u00f1v Turkmenistan",
               "",
               "eur Turkmenistan",
               "",
            };
        final String[] French_Guiana = new String[] {
               "eur Gwiana c\u02bchall",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] New_Caledonia = new String[] {
               "eur c\u02bchoa\u00f1v Kaledonia Nevez",
               "",
               "eur ha\u00f1v Kaledonia Nevez",
               "",
               "eur Kaledonia Nevez",
               "",
            };
        final String[] South_Georgia = new String[] {
               "eur Georgia ar Su",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Yekaterinburg = new String[] {
               "eur c\u02bchoa\u00f1v Yekaterinbourg",
               "",
               "eur ha\u00f1v Yekaterinbourg",
               "",
               "eur Yekaterinbourg",
               "",
            };
        final String[] Africa_Central = new String[] {
               "eur Kreizafrika",
               "CAT",
               "",
               "CAT",
               "",
               "CAT",
            };
        final String[] Africa_Eastern = new String[] {
               "eur Afrika ar Reter",
               "EAT",
               "",
               "EAT",
               "",
               "EAT",
            };
        final String[] Africa_Western = new String[] {
               "eur c\u02bchoa\u00f1v Afrika ar C\u02bchorn\u00f4g",
               "WAT",
               "eur ha\u00f1v Afrika ar C\u02bchorn\u00f4g",
               "WAT",
               "eur Afrika ar C\u02bchorn\u00f4g",
               "WAT",
            };
        final String[] DumontDUrville = new String[] {
               "eur Dumont-d\u2019Urville",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Europe_Central = new String[] {
               "eur c\u02bchoa\u00f1v Kreizeuropa",
               "CET",
               "eur ha\u00f1v Kreizeuropa",
               "CEST",
               "eur Kreizeuropa",
               "CET",
            };
        final String[] Europe_Eastern = new String[] {
               "eur c\u02bchoa\u00f1v Europa ar Reter",
               "EET",
               "eur ha\u00f1v Europa ar Reter",
               "EEST",
               "eur Europa ar Reter",
               "EET",
            };
        final String[] Europe_Western = new String[] {
               "eur c\u02bchoa\u00f1v Europa ar C\u02bchorn\u00f4g",
               "WET",
               "eur ha\u00f1v Europa ar C\u02bchorn\u00f4g",
               "WEST",
               "eur Europa ar C\u02bchorn\u00f4g",
               "WET",
            };
        final String[] Mexico_Pacific = new String[] {
               "eur c\u02bchoa\u00f1v an Habask mec\u02bchikan",
               "MST",
               "eur ha\u00f1v an Habask mec\u02bchikan",
               "MDT",
               "eur an Habask mec\u02bchikan",
               "MT",
            };
        final String[] Africa_Southern = new String[] {
               "eur c\u02bchoa\u00f1v Suafrika",
               "SAST",
               "",
               "SAST",
               "",
               "SAST",
            };
        final String[] America_Central = new String[] {
               "eur c\u02bchoa\u00f1v ar C\u02bchreiz",
               "CST",
               "eur ha\u00f1v ar C\u02bchreiz",
               "CDT",
               "eur ar C\u02bchreiz",
               "CT",
            };
        final String[] America_Eastern = new String[] {
               "eur c\u02bchoa\u00f1v ar Reter",
               "EST",
               "eur ha\u00f1v ar Reter",
               "EST",
               "eur ar Reter",
               "EST",
            };
        final String[] America_Pacific = new String[] {
               "eur c\u02bchoa\u00f1v an Habask",
               "PST",
               "eur ha\u00f1v an Habask",
               "PDT",
               "eur an Habask",
               "PT",
            };
        final String[] French_Southern = new String[] {
               "eur Douaro\u00f9 aostral Fra\u00f1s hag Antarktika",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Gilbert_Islands = new String[] {
               "eur Inizi Gilbert",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Hawaii_Aleutian = new String[] {
               "eur c\u02bchoa\u00f1v Hawaii hag an Aleouted",
               "HST",
               "eur ha\u00f1v Hawaii hag an Aleouted",
               "HST",
               "eur Hawaii hag an Aleouted",
               "HST",
            };
        final String[] Phoenix_Islands = new String[] {
               "eur Inizi Phoenix",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Pierre_Miquelon = new String[] {
               "eur c\u02bchoa\u00f1v Sant-P\u00ear-ha-Mikelon",
               "",
               "eur ha\u00f1v Sant-P\u00ear-ha-Mikelon",
               "",
               "eur Sant-P\u00ear-ha-Mikelon",
               "",
            };
        final String[] America_Mountain = new String[] {
               "eur c\u02bchoa\u00f1v ar Menezio\u00f9",
               "MST",
               "eur ha\u00f1v ar Menezio\u00f9",
               "MST",
               "eur ar Menezio\u00f9",
               "MST",
            };
        final String[] Marshall_Islands = new String[] {
               "eur Inizi Marshall",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Mexico_Northwest = new String[] {
               "eur c\u02bchoa\u00f1v Gwalarn Mec\u02bchiko",
               "",
               "eur ha\u00f1v Gwalarn Mec\u02bchiko",
               "",
               "eur Gwalarn Mec\u02bchiko",
               "",
            };
        final String[] Papua_New_Guinea = new String[] {
               "eur Papoua-Ginea-Nevez",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Australia_Central = new String[] {
               "eur c\u02bchoa\u00f1v Kreizaostralia",
               "ACST",
               "eur ha\u00f1v Kreizaostralia",
               "ACDT",
               "eur Kreizaostralia",
               "ACT",
            };
        final String[] Australia_Eastern = new String[] {
               "eur c\u02bchoa\u00f1v Aostralia ar Reter",
               "AEST",
               "eur ha\u00f1v Aostralia ar Reter",
               "AEDT",
               "eur Aostralia ar Reter",
               "AET",
            };
        final String[] Australia_Western = new String[] {
               "eur c\u02bchoa\u00f1v Aostralia ar C\u02bchorn\u00f4g",
               "AWST",
               "eur ha\u00f1v Aostralia ar C\u02bchorn\u00f4g",
               "AWDT",
               "eur Aostralia ar C\u02bchorn\u00f4g",
               "AWT",
            };
        final String[] Greenland_Eastern = new String[] {
               "eur c\u02bchoa\u00f1v Greunland ar Reter",
               "",
               "eur ha\u00f1v Greunland ar Reter",
               "",
               "eur Greunland ar Reter",
               "",
            };
        final String[] Greenland_Western = new String[] {
               "eur c\u02bchoa\u00f1v Greunland ar C\u02bchorn\u00f4g",
               "",
               "eur ha\u00f1v Greunland ar C\u02bchorn\u00f4g",
               "",
               "eur Greunland ar C\u02bchorn\u00f4g",
               "",
            };
        final String[] Indonesia_Central = new String[] {
               "eur Kreiz Indonezia",
               "WITA",
               "",
               "WITA",
               "",
               "WITA",
            };
        final String[] Indonesia_Eastern = new String[] {
               "eur Indonezia ar Reter",
               "WIT",
               "",
               "WIT",
               "",
               "WIT",
            };
        final String[] Indonesia_Western = new String[] {
               "eur Indonezia ar C\u02bchorn\u00f4g",
               "WIB",
               "",
               "WIB",
               "",
               "WIB",
            };
        final String[] Kazakhstan_Eastern = new String[] {
               "eur Kazakstan ar Reter",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Kazakhstan_Western = new String[] {
               "eur Kazakstan ar C\u02bchorn\u00f4g",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Australia_CentralWestern = new String[] {
               "eur c\u02bchoa\u00f1v Kreizaostralia ar C\u02bchorn\u00f4g",
               "",
               "eur ha\u00f1v Kreizaostralia ar C\u02bchorn\u00f4g",
               "",
               "eur Kreizaostralia ar C\u02bchorn\u00f4g",
               "",
            };
        final Object[][] data = new Object[][] {
            { "America/Los_Angeles", America_Pacific },
            { "America/Denver", America_Mountain },
            { "America/Phoenix", America_Mountain },
            { "America/Chicago", America_Central },
            { "America/New_York", America_Eastern },
            { "America/Indianapolis", America_Eastern },
            { "Pacific/Honolulu", Hawaii_Aleutian },
            { "America/Anchorage", Alaska },
            { "America/Halifax", Atlantic },
            { "America/Sitka", Alaska },
            { "America/St_Johns", Newfoundland },
            { "Europe/Paris", Europe_Central },
            { "GMT", GMT },
            { "Asia/Jerusalem", Israel },
            { "Asia/Tokyo", Japan },
            { "Europe/Bucharest", Europe_Eastern },
            { "Asia/Shanghai", China },
            { "UTC", ETC_UTC },
            { "ACT", Australia_Central },
            { "AET", Australia_Eastern },
            { "ART", Europe_Eastern },
            { "AST", Alaska },
            { "BET", Brasilia },
            { "BST", Bangladesh },
            { "CAT", Africa_Central },
            { "CNT", Newfoundland },
            { "CST", America_Central },
            { "CTT", China },
            { "EAT", Africa_Eastern },
            { "ECT", Europe_Central },
            { "JST", Japan },
            { "MIT", Apia },
            { "NET", Armenia },
            { "NST", New_Zealand },
            { "PLT", Pakistan },
            { "PNT", America_Mountain },
            { "PRT", Atlantic },
            { "PST", America_Pacific },
            { "SST", Solomon },
            { "CST6CDT", America_Central },
            { "EST5EDT", America_Eastern },
            { "Etc/GMT", GMT },
            { "Etc/UTC", ETC_UTC },
            { "MST7MDT", America_Mountain },
            { "PST8PDT", America_Pacific },
            { "Asia/Aden", Arabian },
            { "Asia/Baku", Azerbaijan },
            { "Asia/Dili", East_Timor },
            { "Asia/Gaza", Europe_Eastern },
            { "Asia/Hovd", Hovd },
            { "Asia/Omsk", Omsk },
            { "Asia/Oral", Kazakhstan_Western },
            { "Asia/Aqtau", Kazakhstan_Western },
            { "Asia/Chita", Yakutsk },
            { "Asia/Dhaka", Bangladesh },
            { "Asia/Dubai", Gulf },
            { "Asia/Kabul", Afghanistan },
            { "Asia/Macau", China },
            { "Asia/Qatar", Arabian },
            { "Asia/Seoul", Korea },
            { "Africa/Juba", Africa_Central },
            { "Africa/Lome", GMT },
            { "Asia/Almaty", Kazakhstan_Eastern },
            { "Asia/Anadyr", Anadyr },
            { "Asia/Aqtobe", Kazakhstan_Western },
            { "Asia/Atyrau", Kazakhstan_Western },
            { "Asia/Beirut", Europe_Eastern },
            { "Asia/Brunei", Brunei },
            { "Asia/Harbin", China },
            { "Asia/Hebron", Europe_Eastern },
            { "Asia/Kuwait", Arabian },
            { "Asia/Manila", Philippines },
            { "Asia/Muscat", Gulf },
            { "Asia/Riyadh", Arabian },
            { "Asia/Saigon", Indochina },
            { "Asia/Taipei", Taipei },
            { "Asia/Tehran", Iran },
            { "Europe/Kiev", Europe_Eastern },
            { "Europe/Oslo", Europe_Central },
            { "Europe/Riga", Europe_Eastern },
            { "Europe/Rome", Europe_Central },
            { "Indian/Mahe", Seychelles },
            { "Pacific/Yap", Truk },
            { "Africa/Accra", GMT },
            { "Africa/Cairo", Europe_Eastern },
            { "Africa/Ceuta", Europe_Central },
            { "Africa/Dakar", GMT },
            { "Africa/Lagos", Africa_Western },
            { "Africa/Tunis", Europe_Central },
            { "America/Adak", Hawaii_Aleutian },
            { "America/Lima", Peru },
            { "America/Nome", Alaska },
            { "Asia/Baghdad", Arabian },
            { "Asia/Bahrain", Arabian },
            { "Asia/Bangkok", Indochina },
            { "Asia/Bishkek", Kyrgystan },
            { "Asia/Colombo", India },
            { "Asia/Irkutsk", Irkutsk },
            { "Asia/Jakarta", Indonesia_Western },
            { "Asia/Karachi", Pakistan },
            { "Asia/Kuching", Malaysia },
            { "Asia/Magadan", Magadan },
            { "Asia/Nicosia", Europe_Eastern },
            { "Asia/Rangoon", Myanmar },
            { "Asia/Tbilisi", Georgia },
            { "Asia/Thimphu", Bhutan },
            { "Asia/Yakutsk", Yakutsk },
            { "Asia/Yerevan", Armenia },
            { "Europe/Malta", Europe_Central },
            { "Europe/Minsk", Moscow },
            { "Europe/Sofia", Europe_Eastern },
            { "Europe/Vaduz", Europe_Central },
            { "Indian/Cocos", Cocos },
            { "Pacific/Apia", Apia },
            { "Pacific/Fiji", Fiji },
            { "Pacific/Guam", Chamorro },
            { "Pacific/Niue", Niue },
            { "Pacific/Truk", Truk },
            { "Pacific/Wake", Wake },
            { "SystemV/AST4", Atlantic },
            { "SystemV/CST6", America_Central },
            { "SystemV/EST5", America_Eastern },
            { "SystemV/MST7", America_Mountain },
            { "SystemV/PST8", Pitcairn },
            { "SystemV/YST9", Gambier },
            { "Africa/Asmera", Africa_Eastern },
            { "Africa/Bamako", GMT },
            { "Africa/Bangui", Africa_Western },
            { "Africa/Banjul", GMT },
            { "Africa/Bissau", GMT },
            { "Africa/Douala", Africa_Western },
            { "Africa/Harare", Africa_Central },
            { "Africa/Kigali", Africa_Central },
            { "Africa/Luanda", Africa_Western },
            { "Africa/Lusaka", Africa_Central },
            { "Africa/Malabo", Africa_Western },
            { "Africa/Maputo", Africa_Central },
            { "Africa/Maseru", Africa_Southern },
            { "Africa/Niamey", Africa_Western },
            { "America/Aruba", Atlantic },
            { "America/Bahia", Brasilia },
            { "America/Belem", Brasilia },
            { "America/Boise", America_Mountain },
            { "America/Jujuy", Argentina },
            { "America/Thule", Atlantic },
            { "Asia/Ashgabat", Turkmenistan },
            { "Asia/Calcutta", India },
            { "Asia/Dushanbe", Tajikistan },
            { "Asia/Jayapura", Indonesia_Eastern },
            { "Asia/Katmandu", Nepal },
            { "Asia/Khandyga", Yakutsk },
            { "Asia/Makassar", Indonesia_Central },
            { "Asia/Qostanay", Kazakhstan_Eastern },
            { "Asia/Sakhalin", Sakhalin },
            { "Asia/Tashkent", Uzbekistan },
            { "Asia/Ust-Nera", Vladivostok },
            { "Europe/Athens", Europe_Eastern },
            { "Europe/Berlin", Europe_Central },
            { "Europe/Dublin",
                new String[] {
                    "Amzer keitat Greenwich (AKG)",
                    "GMT",
                    "eur c\u02bchoa\u00f1v Iwerzhon",
                    "IST",
                    "",
                    "GMT",
                }
            },
            { "Europe/Jersey", GMT },
            { "Europe/Lisbon", Europe_Western },
            { "Europe/London",
                new String[] {
                    "Amzer keitat Greenwich (AKG)",
                    "GMT",
                    "eur ha\u00f1v Breizh-Veur",
                    "BST",
                    "",
                    "GMT",
                }
            },
            { "Europe/Madrid", Europe_Central },
            { "Europe/Monaco", Europe_Central },
            { "Europe/Moscow", Moscow },
            { "Europe/Prague", Europe_Central },
            { "Europe/Skopje", Europe_Central },
            { "Europe/Tirane", Europe_Central },
            { "Europe/Vienna", Europe_Central },
            { "Europe/Warsaw", Europe_Central },
            { "Europe/Zagreb", Europe_Central },
            { "Europe/Zurich", Europe_Central },
            { "Indian/Chagos", Indian_Ocean },
            { "Indian/Comoro", Africa_Eastern },
            { "Pacific/Efate", Vanuatu },
            { "Pacific/Nauru", Nauru },
            { "Pacific/Palau", Palau },
            { "SystemV/HST10", Hawaii_Aleutian },
            { "Africa/Abidjan", GMT },
            { "Africa/Algiers", Europe_Central },
            { "Africa/Conakry", GMT },
            { "Africa/Kampala", Africa_Eastern },
            { "Africa/Mbabane", Africa_Southern },
            { "Africa/Nairobi", Africa_Eastern },
            { "Africa/Tripoli", Europe_Eastern },
            { "America/Belize", America_Central },
            { "America/Bogota", Colombia },
            { "America/Cancun", America_Eastern },
            { "America/Cayman", America_Eastern },
            { "America/Cuiaba", Amazon },
            { "America/Guyana", Guyana },
            { "America/Havana", Cuba },
            { "America/Inuvik", America_Mountain },
            { "America/Juneau", Alaska },
            { "America/La_Paz", Bolivia },
            { "America/Maceio", Brasilia },
            { "America/Manaus", Amazon },
            { "America/Merida", America_Central },
            { "America/Nassau", America_Eastern },
            { "America/Panama", America_Eastern },
            { "America/Recife", Brasilia },
            { "America/Regina", America_Central },
            { "Asia/Chongqing", China },
            { "Asia/Hong_Kong", Hong_Kong },
            { "Asia/Pontianak", Indonesia_Western },
            { "Asia/Pyongyang", Korea },
            { "Asia/Qyzylorda", Kazakhstan_Western },
            { "Asia/Samarkand", Uzbekistan },
            { "Asia/Singapore", Singapore },
            { "Asia/Vientiane", Indochina },
            { "Europe/Andorra", Europe_Central },
            { "Europe/Belfast",
                new String[] {
                    "Amzer keitat Greenwich (AKG)",
                    "GMT",
                    "eur ha\u00f1v Breizh-Veur",
                    "BST",
                    "",
                    "GMT",
                }
            },
            { "Europe/Tallinn", Europe_Eastern },
            { "Europe/Vatican", Europe_Central },
            { "Europe/Vilnius", Europe_Eastern },
            { "Indian/Mayotte", Africa_Eastern },
            { "Indian/Reunion", Reunion },
            { "Pacific/Easter", Easter },
            { "Pacific/Kosrae", Kosrae },
            { "Pacific/Majuro", Marshall_Islands },
            { "Pacific/Midway", Samoa },
            { "Pacific/Noumea", New_Caledonia },
            { "Pacific/Ponape", Ponape },
            { "Pacific/Saipan", Chamorro },
            { "Pacific/Tahiti", Tahiti },
            { "Pacific/Tarawa", Gilbert_Islands },
            { "Pacific/Wallis", Wallis },
            { "Africa/Blantyre", Africa_Central },
            { "Africa/Djibouti", Africa_Eastern },
            { "Africa/Freetown", GMT },
            { "Africa/Gaborone", Africa_Central },
            { "Africa/Khartoum", Africa_Central },
            { "Africa/Kinshasa", Africa_Western },
            { "Africa/Monrovia", GMT },
            { "Africa/Ndjamena", Africa_Western },
            { "Africa/Sao_Tome", GMT },
            { "Africa/Timbuktu", GMT },
            { "Africa/Windhoek", Africa_Central },
            { "America/Antigua", Atlantic },
            { "America/Caracas", Venezuela },
            { "America/Cayenne", French_Guiana },
            { "America/Cordoba", Argentina },
            { "America/Creston", America_Mountain },
            { "America/Curacao", Atlantic },
            { "America/Detroit", America_Eastern },
            { "America/Godthab", Greenland_Western },
            { "America/Grenada", Atlantic },
            { "America/Iqaluit", America_Eastern },
            { "America/Jamaica", America_Eastern },
            { "America/Managua", America_Central },
            { "America/Marigot", Atlantic },
            { "America/Mendoza", Argentina },
            { "America/Moncton", Atlantic },
            { "America/Nipigon", America_Eastern },
            { "America/Noronha", Noronha },
            { "America/Ojinaga", America_Central },
            { "America/Tijuana", America_Pacific },
            { "America/Toronto", America_Eastern },
            { "America/Tortola", Atlantic },
            { "America/Yakutat", Alaska },
            { "Asia/Choibalsan", Mongolia },
            { "Asia/Phnom_Penh", Indochina },
            { "Atlantic/Azores", Azores },
            { "Atlantic/Canary", Europe_Western },
            { "Atlantic/Faeroe", Europe_Western },
            { "Australia/Eucla", Australia_CentralWestern },
            { "Australia/Perth", Australia_Western },
            { "Europe/Belgrade", Europe_Central },
            { "Europe/Brussels", Europe_Central },
            { "Europe/Budapest", Europe_Central },
            { "Europe/Busingen", Europe_Central },
            { "Europe/Chisinau", Europe_Eastern },
            { "Europe/Guernsey", GMT },
            { "Europe/Helsinki", Europe_Eastern },
            { "Europe/Sarajevo", Europe_Central },
            { "Europe/Uzhgorod", Europe_Eastern },
            { "Indian/Maldives", Maldives },
            { "Pacific/Chatham", Chatham },
            { "Pacific/Fakaofo", Tokelau },
            { "Pacific/Gambier", Gambier },
            { "Pacific/Norfolk", Norfolk },
            { "SystemV/AST4ADT", Atlantic },
            { "SystemV/CST6CDT", America_Central },
            { "SystemV/EST5EDT", America_Eastern },
            { "SystemV/MST7MDT", America_Mountain },
            { "SystemV/PST8PDT", America_Pacific },
            { "SystemV/YST9YDT", Alaska },
            { "Africa/Bujumbura", Africa_Central },
            { "Africa/Mogadishu", Africa_Eastern },
            { "America/Anguilla", Atlantic },
            { "America/Asuncion", Paraguay },
            { "America/Barbados", Atlantic },
            { "America/Dominica", Atlantic },
            { "America/Edmonton", America_Mountain },
            { "America/Mazatlan", Mexico_Pacific },
            { "America/Miquelon", Pierre_Miquelon },
            { "America/Montreal", America_Eastern },
            { "America/Resolute", America_Central },
            { "America/Santarem", Brasilia },
            { "America/Santiago", Chile },
            { "America/Shiprock", America_Mountain },
            { "America/St_Kitts", Atlantic },
            { "America/St_Lucia", Atlantic },
            { "America/Winnipeg", America_Central },
            { "Antarctica/Davis", Davis },
            { "Antarctica/Syowa", Syowa },
            { "Antarctica/Troll", GMT },
            { "Asia/Krasnoyarsk", Krasnoyarsk },
            { "Asia/Novosibirsk", Novosibirsk },
            { "Asia/Ulaanbaatar", Mongolia },
            { "Asia/Vladivostok", Vladivostok },
            { "Atlantic/Bermuda", Atlantic },
            { "Atlantic/Madeira", Europe_Western },
            { "Atlantic/Stanley", Falkland },
            { "Australia/Currie", Australia_Eastern },
            { "Australia/Darwin", Australia_Central },
            { "Australia/Hobart", Australia_Eastern },
            { "Australia/Sydney", Australia_Eastern },
            { "Europe/Amsterdam", Europe_Central },
            { "Europe/Gibraltar", Europe_Central },
            { "Europe/Ljubljana", Europe_Central },
            { "Europe/Mariehamn", Europe_Eastern },
            { "Europe/Podgorica", Europe_Central },
            { "Europe/Stockholm", Europe_Central },
            { "Europe/Volgograd", Volgograd },
            { "Indian/Christmas", Christmas },
            { "Indian/Kerguelen", French_Southern },
            { "Indian/Mauritius", Mauritius },
            { "Pacific/Auckland", New_Zealand },
            { "Pacific/Funafuti", Tuvalu },
            { "Pacific/Johnston", Hawaii_Aleutian },
            { "Pacific/Pitcairn", Pitcairn },
            { "Africa/Libreville", Africa_Western },
            { "Africa/Lubumbashi", Africa_Central },
            { "Africa/Nouakchott", GMT },
            { "Africa/Porto-Novo", Africa_Western },
            { "America/Araguaina", Brasilia },
            { "America/Boa_Vista", Amazon },
            { "America/Catamarca", Argentina },
            { "America/Chihuahua", America_Central },
            { "America/Fortaleza", Brasilia },
            { "America/Glace_Bay", Atlantic },
            { "America/Goose_Bay", Atlantic },
            { "America/Guatemala", America_Central },
            { "America/Guayaquil", Ecuador },
            { "America/Matamoros", America_Central },
            { "America/Menominee", America_Central },
            { "America/Monterrey", America_Central },
            { "America/Sao_Paulo", Brasilia },
            { "America/St_Thomas", Atlantic },
            { "America/Vancouver", America_Pacific },
            { "Antarctica/Mawson", Mawson },
            { "Antarctica/Vostok", Vostok },
            { "Asia/Kuala_Lumpur", Malaysia },
            { "Asia/Novokuznetsk", Krasnoyarsk },
            { "Europe/Bratislava", Europe_Central },
            { "Europe/Copenhagen", Europe_Central },
            { "Europe/Luxembourg", Europe_Central },
            { "Europe/San_Marino", Europe_Central },
            { "Europe/Simferopol", Moscow },
            { "Europe/Zaporozhye", Europe_Eastern },
            { "Pacific/Enderbury", Phoenix_Islands },
            { "Pacific/Galapagos", Galapagos },
            { "Pacific/Kwajalein", Marshall_Islands },
            { "Pacific/Marquesas", Marquesas },
            { "Pacific/Pago_Pago", Samoa },
            { "Pacific/Rarotonga", Cook },
            { "Pacific/Tongatapu", Tonga },
            { "Africa/Addis_Ababa", Africa_Eastern },
            { "Africa/Brazzaville", Africa_Western },
            { "Africa/Ouagadougou", GMT },
            { "America/Costa_Rica", America_Central },
            { "America/Grand_Turk", America_Eastern },
            { "America/Guadeloupe", Atlantic },
            { "America/Hermosillo", Mexico_Pacific },
            { "America/Kralendijk", Atlantic },
            { "America/Louisville", America_Eastern },
            { "America/Martinique", Atlantic },
            { "America/Metlakatla", Alaska },
            { "America/Montevideo", Uruguay },
            { "America/Montserrat", Atlantic },
            { "America/Paramaribo", Suriname },
            { "America/St_Vincent", Atlantic },
            { "Antarctica/McMurdo", New_Zealand },
            { "Antarctica/Rothera", Rothera },
            { "Asia/Yekaterinburg", Yekaterinburg },
            { "Atlantic/Jan_Mayen", Europe_Central },
            { "Atlantic/Reykjavik", GMT },
            { "Atlantic/St_Helena", GMT },
            { "Australia/Adelaide", Australia_Central },
            { "Australia/Brisbane", Australia_Eastern },
            { "Australia/Lindeman", Australia_Eastern },
            { "Europe/Isle_of_Man", GMT },
            { "Europe/Kaliningrad", Europe_Eastern },
            { "Pacific/Kiritimati", Line_Islands },
            { "Africa/Johannesburg", Africa_Southern },
            { "America/El_Salvador", America_Central },
            { "America/Fort_Nelson", America_Mountain },
            { "America/Mexico_City", America_Central },
            { "America/Pangnirtung", America_Eastern },
            { "America/Porto_Velho", Amazon },
            { "America/Puerto_Rico", Atlantic },
            { "America/Rainy_River", America_Central },
            { "America/Tegucigalpa", America_Central },
            { "America/Thunder_Bay", America_Eastern },
            { "America/Yellowknife", America_Mountain },
            { "Arctic/Longyearbyen", Europe_Central },
            { "Atlantic/Cape_Verde", Cape_Verde },
            { "Australia/Lord_Howe", Lord_Howe },
            { "Australia/Melbourne", Australia_Eastern },
            { "Indian/Antananarivo", Africa_Eastern },
            { "Pacific/Guadalcanal", Solomon },
            { "Africa/Dar_es_Salaam", Africa_Eastern },
            { "America/Blanc-Sablon", Atlantic },
            { "America/Buenos_Aires", Argentina },
            { "America/Campo_Grande", Amazon },
            { "America/Danmarkshavn", GMT },
            { "America/Dawson_Creek", America_Mountain },
            { "America/Indiana/Knox", America_Central },
            { "America/Rankin_Inlet", America_Central },
            { "America/Santa_Isabel", Mexico_Northwest },
            { "America/Scoresbysund", Greenland_Eastern },
            { "Antarctica/Macquarie", Australia_Eastern },
            { "Pacific/Port_Moresby", Papua_New_Guinea },
            { "America/Cambridge_Bay", America_Mountain },
            { "America/Ciudad_Juarez", America_Mountain },
            { "America/Coral_Harbour", America_Eastern },
            { "America/Indiana/Vevay", America_Eastern },
            { "America/Lower_Princes", Atlantic },
            { "America/Port_of_Spain", Atlantic },
            { "America/Santo_Domingo", Atlantic },
            { "America/St_Barthelemy", Atlantic },
            { "America/Swift_Current", America_Central },
            { "Antarctica/South_Pole", New_Zealand },
            { "Australia/Broken_Hill", Australia_Central },
            { "America/Bahia_Banderas", America_Central },
            { "America/Port-au-Prince", America_Eastern },
            { "Atlantic/South_Georgia", South_Georgia },
            { "America/Argentina/Salta", Argentina },
            { "America/Indiana/Marengo", America_Eastern },
            { "America/Indiana/Winamac", America_Eastern },
            { "America/Argentina/Tucuman", Argentina },
            { "America/Argentina/Ushuaia", Argentina },
            { "America/Indiana/Tell_City", America_Central },
            { "America/Indiana/Vincennes", America_Eastern },
            { "Antarctica/DumontDUrville", DumontDUrville },
            { "timezone.excity.Asia/Baku", "Bakou" },
            { "America/Argentina/La_Rioja", Argentina },
            { "America/Argentina/San_Juan", Argentina },
            { "America/Argentina/San_Luis", Argentina },
            { "America/Indiana/Petersburg", America_Eastern },
            { "timezone.excity.Asia/Chita", "Tchita" },
            { "timezone.excity.Asia/Kabul", "Kaboul" },
            { "timezone.excity.Asia/Macau", "Macau" },
            { "America/Kentucky/Monticello", America_Eastern },
            { "America/North_Dakota/Beulah", America_Central },
            { "America/North_Dakota/Center", America_Central },
            { "timezone.excity.Africa/Lome", "Lom\u00e9" },
            { "timezone.excity.Asia/Anadyr", "Anadyr\u02bc" },
            { "timezone.excity.Asia/Beirut", "Bayrut" },
            { "timezone.excity.Asia/Kuwait", "Koweit" },
            { "timezone.excity.Asia/Muscat", "Masqat" },
            { "timezone.excity.Asia/Saigon", "K\u00ear H\u00f4-Chi-Minh" },
            { "timezone.excity.Asia/Urumqi", "\u00dcr\u00fcmqi" },
            { "timezone.excity.Etc/Unknown", "k\u00ear dianav" },
            { "timezone.excity.Europe/Kiev", "Kiev" },
            { "timezone.excity.Europe/Rome", "Roma" },
            { "timezone.excity.Africa/Cairo", "Kaero" },
            { "timezone.excity.Africa/Tunis", "Tuniz" },
            { "timezone.excity.Asia/Bahrain", "Bahrein" },
            { "timezone.excity.Asia/Colombo", "Kolamba" },
            { "timezone.excity.Asia/Nicosia", "Levkos\u00eda" },
            { "timezone.excity.Europe/Minsk", "Mensk" },
            { "timezone.excity.Europe/Paris", "Pariz" },
            { "timezone.excity.Indian/Cocos", "Kokoz" },
            { "timezone.excity.Pacific/Fiji", "Fidji" },
            { "timezone.excity.America/Belem", "Bel\u00e9m" },
            { "timezone.excity.America/Thule", "Q\u00e2n\u00e2q" },
            { "timezone.excity.Asia/Calcutta", "Calcutta" },
            { "timezone.excity.Asia/Damascus", "Damask" },
            { "timezone.excity.Asia/Tashkent", "Toshkent" },
            { "timezone.excity.Europe/Athens", "Aten" },
            { "timezone.excity.Europe/Dublin", "Dulenn" },
            { "timezone.excity.Europe/Jersey", "Jerzenez" },
            { "timezone.excity.Europe/Lisbon", "Lisboa" },
            { "timezone.excity.Europe/London", "Londrez" },
            { "timezone.excity.Europe/Moscow", "Moskov" },
            { "timezone.excity.Europe/Prague", "Praha" },
            { "timezone.excity.Europe/Tirane", "Tiran\u00eb" },
            { "timezone.excity.Europe/Warsaw", "Varsovia" },
            { "timezone.excity.Indian/Comoro", "Komorez" },
            { "America/Argentina/Rio_Gallegos", Argentina },
            { "America/North_Dakota/New_Salem", America_Central },
            { "timezone.excity.Africa/Algiers", "Aljer" },
            { "timezone.excity.Africa/Tripoli", "Tarabulus (Tripoli)" },
            { "timezone.excity.America/Bogota", "Bogot\u00e1" },
            { "timezone.excity.America/Havana", "La Habana" },
            { "timezone.excity.America/Panama", "Panam\u00e1" },
            { "timezone.excity.Asia/Jerusalem", "Jeruzalem" },
            { "timezone.excity.Asia/Kamchatka", "Kamtchatka" },
            { "timezone.excity.Asia/Pyongyang", "P\u02bcyongyang" },
            { "timezone.excity.Asia/Singapore", "Singapour" },
            { "timezone.excity.Asia/Vientiane", "Viangchan" },
            { "timezone.excity.Europe/Vatican", "Vatikan" },
            { "timezone.excity.Indian/Reunion", "Re\u00fcnion" },
            { "timezone.excity.Pacific/Easter", "Enez Pask" },
            { "timezone.excity.Africa/El_Aaiun", "La\u02bcYoun" },
            { "timezone.excity.Africa/Ndjamena", "N\u02bcDjamena" },
            { "timezone.excity.America/Godthab", "Nuuk (Godth\u00e5b)" },
            { "timezone.excity.America/Jamaica", "Jamaika" },
            { "timezone.excity.Asia/Phnom_Penh", "Phnum P\u00e9nh" },
            { "timezone.excity.Atlantic/Azores", "Azorez" },
            { "timezone.excity.Atlantic/Canary", "Kanariez" },
            { "timezone.excity.Atlantic/Faeroe", "Faero" },
            { "timezone.excity.Europe/Belgrade", "Beograd" },
            { "timezone.excity.Europe/Brussels", "Brusel" },
            { "timezone.excity.Europe/Guernsey", "Gwernenez" },
            { "timezone.excity.Indian/Maldives", "Maldivez" },
            { "timezone.excity.Africa/Mogadishu", "Muqdisho" },
            { "timezone.excity.America/Miquelon", "Mikelon" },
            { "timezone.excity.America/St_Johns", "Saint John\u02bcs" },
            { "timezone.excity.America/St_Kitts", "Saint Kitts" },
            { "timezone.excity.America/St_Lucia", "Saint Lucia" },
            { "timezone.excity.Atlantic/Bermuda", "Bermudez" },
            { "timezone.excity.Europe/Bucharest", "Bukarest" },
            { "timezone.excity.Europe/Gibraltar", "Jibraltar" },
            { "timezone.excity.Europe/Mariehamn", "Marjehamn" },
            { "timezone.excity.Indian/Kerguelen", "Kergelenn" },
            { "timezone.excity.Indian/Mauritius", "Moris" },
            { "timezone.excity.Pacific/Honolulu", "Honolulu" },
            { "timezone.excity.Africa/Casablanca", "Dar el Beida (Casablanca)" },
            { "timezone.excity.America/Sao_Paulo", "S\u00e3o Paulo" },
            { "timezone.excity.Europe/Copenhagen", "Kopenhagen" },
            { "timezone.excity.Europe/Luxembourg", "Luksembourg" },
            { "timezone.excity.Pacific/Galapagos", "Gal\u00e1pagos" },
            { "timezone.excity.Pacific/Marquesas", "Markiz" },
            { "timezone.excity.Africa/Addis_Ababa", "Adis Abeba" },
            { "timezone.excity.America/Guadeloupe", "Gwadeloup" },
            { "timezone.excity.America/Martinique", "Martinik" },
            { "timezone.excity.America/St_Vincent", "Sant Visant" },
            { "timezone.excity.Asia/Yekaterinburg", "Yekaterinbourg" },
            { "timezone.excity.Atlantic/Reykjavik", "Reykjav\u00edk" },
            { "timezone.excity.Atlantic/St_Helena", "Saint Helena" },
            { "timezone.excity.Europe/Isle_of_Man", "Manav" },
            { "timezone.excity.America/El_Salvador", "Salvador" },
            { "timezone.excity.America/Mexico_City", "K\u00ear Vec\u02bchiko" },
            { "timezone.excity.Atlantic/Cape_Verde", "Kab Glas" },
            { "timezone.excity.America/St_Barthelemy", "Saint Barth\u00e9lemy" },
            { "timezone.excity.Atlantic/South_Georgia", "Georgia ar Su" },
        };
        return data;
    }
}
